@@ -1,5 +1,8 @@
 package Ocsinventory::Agent::Backend::OS::Linux::Distro::LSB;
 
+use vars qw($runMeIfTheseChecksFailed);
+$runMeIfTheseChecksFailed = ["Ocsinventory::Agent::Backend::OS::Linux::Distro::NonLSB"];
+
 sub check {
     my $params = shift;
     my $common = $params->{common};
@@ -10,8 +13,8 @@ sub run {
     my $params = shift;
     my $common = $params->{common};
 
-    my $release;
-    chomp($release =`lsb_release -is`);
+    my $OSname;
+    chomp($OSname =`lsb_release -is`);
 
     my $OSversion;
     chomp($OSversion =`lsb_release -rs`);
@@ -19,6 +22,8 @@ sub run {
     my $OSComment;
     chomp($OSComment =`uname -v`);
 
+    my $release = "$OSname $OSVersion";
+
     $common->setHardware({ 
         OSNAME => $release,
         OSVERSION => $OSversion,
