@@ -3,8 +3,10 @@ package Ocsinventory::Agent::Backend::Virtualization::Docker;
 use strict;
 
 sub check { 
-    return(undef) unless -r '/usr/bin/docker';
-    return 1;
+    my $params = shift;
+    my $common = $params->{common};
+
+    return unless $common->can_run("docker");
 }
 
 my @image;
