@@ -14,6 +14,8 @@ use strict;
 no strict 'refs';
 use warnings;
 
+use Encode qw(encode);
+
 =head1 NAME
 
 Ocsinventory::Agent::Common - give common methods to other modules
@@ -99,6 +101,14 @@ Add a CPU in the inventory.
 
 Add an user in the list of logged user.
 
+=item addLocalUser()
+
+Add local users in the inventory.
+
+=item addLocalGroup()
+
+Add local groups in the inventory.
+
 =item addPrinter()
 
 Add a printer in the inventory.
@@ -190,7 +200,7 @@ sub addInput {
 
     my $content = {};
 
-    foreach my $key (qw/DESCRIPTION INTERFACE MANUFACTURER SERIAL TYPE/) {
+    foreach my $key (qw/DESCRIPTION INTERFACE MANUFACTURER CAPTION POINTTYPE TYPE/) {
         if (exists $args->{$key}) {
             $content->{$key}[0] = $args->{$key} if $args->{$key};
         }
@@ -352,7 +362,7 @@ sub addSoftware {
 
     my $content = {};
 
-    foreach my $key (qw/COMMENTS FILESIZE FOLDER FROM INSTALLDATE NAME PUBLISHER VERSION/) {
+    foreach my $key (qw/STATUS ARCHITECTURE COMMENTS FILESIZE FOLDER FROM INSTALLDATE NAME PUBLISHER VERSION/) {
         if (exists $args->{$key}) {
             $content->{$key}[0] = $args->{$key} if $args->{$key};
         }
@@ -472,7 +482,7 @@ sub addRepo {
 
     my $content = {};
 
-    foreach my $key (qw/BASEURL ENABLED FINGERPRINTS FILENAME MIRROR NAME PACKAGES PRIORITY REVISION SIGNATURE SIZE TAG UPDATED/) {
+    foreach my $key (qw/BASEURL ENABLED EXCLUDE EXPIRE EXPIRED FILENAME LASTUPDATED MIRRORS NAME PKGS REVISION SIZE UPDATED/) {
         if (exists $args->{$key}) {
             $content->{$key}[0] = $args->{$key} if $args->{$key};
         }
@@ -499,7 +509,7 @@ sub setHardware {
 
     foreach my $key (qw/USERID OSVERSION PROCESSORN OSCOMMENTS CHECKSUM
     PROCESSORT NAME PROCESSORS SWAP ETIME TYPE OSNAME IPADDR WORKGROUP
-    DESCRIPTION MEMORY UUID DNS LASTLOGGEDUSER
+    DESCRIPTION MEMORY UUID DNS LASTLOGGEDUSER INSTALLDATE
     DATELASTLOGGEDUSER DEFAULTGATEWAY VMSYSTEM/) {
 
         if (exists $args->{$key}) {
@@ -533,7 +543,7 @@ sub addCPU {
 
     my $content = {};
 
-    foreach my $key (qw/CORES CPUARCH CPUSTATUS CURRENT_SPEED DATA_WIDTH HPT L2CACHESIZE MANUFACTURER NBSOCKET SERIALNUMBER SOCKET SPEED TYPE VOLTAGE LOGICAL_CPUS/) {
+    foreach my $key (qw/CORES CPUARCH CPUSTATUS CURRENT_SPEED DATA_WIDTH HPT L2CACHESIZE LOGICAL_CPUS MANUFACTURER NBSOCKET SERIALNUMBER SOCKET SPEED THREADS TYPE VOLTAGE LOGICAL_CPUS/) {
         if (exists $args->{$key}) {
             $content->{$key}[0] = $args->{$key} if $args->{$key};
         }
@@ -582,6 +592,37 @@ sub addUser {
 
 }
 
+sub addLocalUser {
+    my ($self, $args) = @_;
+    my $xmltags = $self->{xmltags};
+
+    my $content = {};
+
+    foreach my $key (qw/GID HOME ID_USER LOGIN NAME SHELL/) {
+        if (exists $args->{$key}) {
+            $content->{$key}[0] = $args->{$key} if $args->{$key};
+        }
+    }
+
+    push @{$xmltags->{LOCAL_USERS}}, $content;
+
+}
+
+sub addLocalGroup {
+    my ($self, $args) = @_;
+    my $xmltags = $self->{xmltags};
+
+    my $content = {};
+
+    foreach my $key (qw/ID_GROUP MEMBER NAME/) {
+        if (exists $args->{$key}) {
+            $content->{$key}[0] = $args->{$key} if $args->{$key};
+        }
+    }
+
+    push @{$xmltags->{LOCAL_GROUPS}}, $content;
+
+}
 sub addPrinter {
     my ($self, $args) = @_;
     my $xmltags = $self->{xmltags};
@@ -668,6 +709,22 @@ sub addCamera {
     push @{$xmltags->{RUNNING_PROCESSES}}, $content;
 }
 
+sub addPSU {
+    my ($self, $args) = @_;
+    my $xmltags = $self->{xmltags};
+
+    my $content = {};
+
+    foreach my $key (qw/HOTREPLACEABLE LOCATION MANUFACTURER NAME PARTNUMBER PLUGGED POWERMAX SERIALNUMBER STATUS/){
+        if (exists $args->{$key}) {
+            $content->{$key}[0] = $args->{$key} if $args->{$key};
+        }
+    }
+
+    push @{$xmltags->{POWERSUPPLIES}}, $content;
+
+}
+
 sub addIpDiscoverEntry {
     my ($self, $args) = @_;
     my $xmltags = $self->{xmltags};
@@ -854,6 +911,20 @@ sub addSnmpNetwork {
     push @{$xmltags->{NETWORKS}},$content;
 }
 
+sub addSnmpBackPlane {
+    my ($self,$args) = @_;
+    my $xmltags = $self->{xmltags};
+    my $content = {};
+
+    foreach my $key (qw/DESCRIPTION FIRMWARE MANUFACTURER REFERENCE SERIALNUMBER TYPE/) {
+        if (exists $args->{$key}) {
+            $content->{$key}[0] = $args->{$key};
+        }
+    }
+
+    push @{$xmltags->{BACKPLANE}},$content;
+}
+
 sub addSnmpCard {
     my ($self,$args) = @_;
     my $xmltags = $self->{xmltags};
@@ -978,30 +1049,12 @@ sub cleanXml {
 
     my $logger = $self->{logger};
 
-    my $clean_content;
+    my $clean_content = encode('UTF-8', $content, Encode::FB_DEFAULT | Encode::LEAVE_SRC | Encode::FB_XMLCREF);
+    $clean_content =~ tr/\x00-\x08\x0B\x0C\x0E-\x1F//d;  # remove forbidden char in XML
 
-    # To avoid strange breakage I remove the unprintable characters in the XML
-    foreach (split "\n", $content) {
-        if (! m/\A(
-            [\x09\x0A\x0D\x20-\x7E]            # ASCII
-            | [\xC2-\xDF][\x80-\xBF]             # non-overlong 2-byte
-            |  \xE0[\xA0-\xBF][\x80-\xBF]        # excluding overlongs
-            | [\xE1-\xEC\xEE\xEF][\x80-\xBF]{2}  # straight 3-byte
-            |  \xED[\x80-\x9F][\x80-\xBF]        # excluding surrogates
-            |  \xF0[\x90-\xBF][\x80-\xBF]{2}     # planes 1-3
-            | [\xF1-\xF3][\x80-\xBF]{3}          # planes 4-15
-            |  \xF4[\x80-\x8F][\x80-\xBF]{2}     # plane 16
-        )*\z/x) {
-            s/[[:cntrl:]]//g;
-            $self->{logger}->debug("non utf-8 '".$_."'");
-        }
+    $logger->debug("cleanXml changed content") if ($content ne $clean_content);
 
-        # Is that a good idea. Intent to drop some nasty char
-        # s/[A-z0-9_\-<>\/:\.,#\ \?="'\(\)]//g;
-        $clean_content .= $_."\n";
-  }
-
-  return $clean_content;
+    return $clean_content."\n";
 }
 
 #Subroutine to read XML structure (returned by XML::Simple::XMLin) and encode content in utf8.
@@ -1017,7 +1070,7 @@ sub readXml {
         } else {  #Not a forced array in XML parsing
            if (ref ($content->{$key}) =~ /^HASH$/ && !keys %{$content->{$key}}) {  # If empty hash from XMLin()
                $content->{$key} = '';
-           } else { utf8::encode($content->{$key}) };
+           } else { encode('UTF-8', $content->{$key}, Encode::FB_DEFAULT) };
         }
     }
     return $content;
@@ -1034,7 +1087,7 @@ sub parseXmlArray {
             } else {  #Not a forced array in XML parsing
                 if (ref ($hash->{$key}) =~ /^HASH$/ && !keys %{$hash->{$key}}) {  # If empty hash from XMLin()
                     $hash->{$key} = '';
-                } else { utf8::encode($hash->{$key}) };
+                } else { encode('UTF-8', $hash->{$key}, Encode::FB_DEFAULT) };
             }
         }
     }
@@ -1081,6 +1134,45 @@ sub get_sysprofile_devices_names {
     return $names;
 }
 
+# Function getDmidecodeInfos.
+#
+sub getDmidecodeInfos {
+    my @dmidecode=`dmidecode`;
+
+    my ($info, $block, $type);
+
+    foreach my $line (@dmidecode){
+        chomp $line;
+        if ($line =~ /DMI type (\d+)/) {
+            if ($block) {
+                push (@{$info->{$type}}, $block);
+                undef $block;
+            }
+            $type=$1;
+            next;
+        }
+        next unless defined $type;
+        next unless $line =~ /^\s+ ([^:]+) : \s (.*\S)/x;
+        next if
+            $2 eq 'N/A' ||
+            $2 eq 'Not Specified' ||
+            $2 eq 'Not Present' ||
+            $2 eq 'Unknown' ||
+            $2 eq '<BAD INDEX>' ||
+            $2 eq '<OUT OF SPEC>' ||
+            $2 eq '<OUT OF SPEC><OUT OF SPEC>';
+        $block->{$1} = $2;
+    }
+    if ($block) {
+        push(@{$info->{$type}}, $block);
+    }
+
+    return if keys %{$info} < 2;
+
+    return $info;
+
+}
+
 ### Generic shared subroutines #####
 
 sub can_run {
