@@ -3,7 +3,7 @@ package Ocsinventory::Agent::Config;
 use strict;
 use Getopt::Long;
 
-our $VERSION = '2.4.2';
+our $VERSION = '2.10.0';
 
 my $basedir = '';
 my $default = {
@@ -37,10 +37,13 @@ my $default = {
     'scanhomedirs' => 0,
     'ssl' => 1,
     'ca' => '',
+    'snmp' => 0,
+    'snmptimeout' => 3,
+    'snmpretry' => 2,
 
     # Other values that can't be changed with the
     # CLI parameters
-    'VERSION'   => $VERSION,
+    'version'   => $VERSION,
     'deviceid'  => '',
     'basevardir'=>  $basedir.'/var/lib/ocsinventory-agent',
     'logdir'    =>  $basedir.'/var/log/ocsinventory-agent',
@@ -86,7 +89,7 @@ sub loadFromCfgFile {
 
     $self->{configfile} = $file;
 
-    if (!open (CONFIG, "<".$file)) {
+    if (!open (CONFIG, '<'.$file)) {
         print(STDERR "Config: Failed to open $file\n");
 	    return $config;
     }
@@ -100,7 +103,7 @@ sub loadFromCfgFile {
             $val =~ s/\s+$//;
             $val =~ s/^'(.*)'$/$1/;
             $val =~ s/^"(.*)"$/$1/;
-            $self->{config}{$key} = $val;
+            $self->{config}{lc($key)} = $val;
         }
     }
     close CONFIG;
@@ -137,10 +140,13 @@ sub loadUserParams {
 		"nolocal"        =>   \$self->{config}{nolocal},
 		"ssl=s"            =>   \$self->{config}{ssl},
 		"ca=s"            =>   \$self->{config}{ca},
+        "snmp=s"            =>   \$self->{config}{snmp},
+        "snmptimeout=s"   =>   \$self->{config}{snmptimeout},
+        "snmpretry=s"     =>   \$self->{config}{snmpretry},
 	);
 
 	$self->help() if (!GetOptions(%options) || $self->{config}{help});
-	$self->version() if $self->{config}{version};
+	$self->version() if $self->{config}{version} eq 1;
 }
 
 
@@ -181,8 +187,8 @@ sub help {
     print STDERR "\t--nosoftware        do not return installed software list (".$self->{config}{nosoftware}.")\n";
     print STDERR "\t--delaytime	      set a max delay time (in second) if no PROLOG_FREQ is set (".$self->{config}{delaytime}.")\n";
     print STDERR "\t--scan-homedirs     permit to scan home user directories (".$self->{config}{scanhomedirs}.")\n" ;
-    print STDERR "\t--ssl=0|1           disable or enable SSL communications check\n" ;
-    print STDERR "\t--ca=FILE           path to CA certificate chain file in PEM format\n" ;
+    print STDERR "\t--ssl=0|1           disable or enable SSL communications check (".$self->{config}{ssl}.")\n" ;
+    print STDERR "\t--ca=FILE           path to CA certificates file in PEM format (".$self->{config}{ca}.")\n" ;
 
     print STDERR "\n";
     print STDERR "Manpage:\n";
