@@ -5,6 +5,7 @@ use strict;
 use lib 'lib';
 
 use Cwd;
+use MIME::Base64;
 use Ocsinventory::Agent::Config;
 
 
@@ -25,6 +26,7 @@ my $nossl;
 my $download;
 my $snmp;
 my $now;
+my $nosoftware;
 
 
 for $option (@ARGV){
@@ -60,8 +62,10 @@ for $option (@ARGV){
         $config->{ca} = $1;
     } elsif($option=~/--download$/){
         $download = 1;
+    } elsif($option=~/--nosoftware$/){
+        $nosoftware = 1;
     } elsif($option=~/--snmp$/){
-        $snmp = 1;
+        $config->{snmp} = 1;
     } elsif($option=~/--now$/){
         $now = 1;
     } elsif($option=~/--help/ || $option=~/-h/) {
@@ -80,7 +84,8 @@ Usage :
 \t--debug                       activate debug mode configuration option while installing OCS Inventory NG Unix Unified agent
 \t--logfile=path                set OCS Inventory NG Unix Unified agent log file path (if needed) 
 \t--nossl                       disable SSL CA verification configuration option while installing OCS Inventory NG Unix Unified agent (not recommended)
-\t--ca=path                     set OCS Inventory NG Unix Unified agent CA certificate chain file path
+\t--ca=path                     set OCS Inventory NG Unix Unified agent CA certificates file path
+\t--nosoftware                  disable software inventory
 \t--download                    activate package deployment feature while installing OCS Inventory NG Unix Unified agent
 \t--snmp                        activate SNMP scans feature while installing OCS Inventory NG Unix Unified agent
 \t--now                         launch OCS Inventory NG Unix Unified agent after installation
@@ -104,14 +109,24 @@ unless ($config->{basevardir}) {
     } elsif ($^O =~ /bsd/) {
         $config->{basevardir} = '/var/db/ocsinventory-agent';
     } else { 
-        $config->{basevardir} = '/var/lib/ocsinventory-agent'
+        $config->{basevardir} = '/var/lib/ocsinventory-agent';
     }
 }
 
+# Default value of SNMP timeout
+unless ($config->{snmptimeout}) {
+    $config->{snmptimeout} = 3;
+}
+
+# Default value of SNMP retry
+unless ($config->{snmpretry}) {
+    $config->{snmpretry} = 2;
+}
+
 
 ############ Asking for questions ##############
 unless ($nowizard) {
-    if (!ask_yn("Do you want to configure the agent", 'y')) {
+    if (!ask_yn("Do you want to configure the agent?", 'y')) {
          exit 0;
     }
   
@@ -130,7 +145,7 @@ unless ($nowizard) {
     }
 
     #Old unix agent
-    if (ask_yn("Should the old unix_agent settings be imported ?", 'y')) {
+    if (ask_yn("Should the old unix_agent settings be imported?", 'y')) {
         $old_unix_config=1;
     }
 
@@ -162,25 +177,27 @@ unless ($nowizard) {
     #Getting credentials if needed
     if (ask_yn ("Do you need credential for the server? (You probably don't)", 'n')) {
         $config->{user} = promptUser("user", $config->{user});
+        $config->{user} = MIME::Base64::encode_base64($config->{user});
         $config->{password} = promptUser("password");
+        $config->{password} = MIME::Base64::encode_base64($config->{password});
         print "[info] The realm can be found in the login popup of your Internet browser.\n[info] In general, it's something like 'Restricted Area'.\n";
         $config->{realm} = promptUser("realm");
     }
 
     #Getting tag
     unless ($config->{tag}){
-        if (ask_yn('Do you want to apply an administrative tag on this machine', 'y')) {
+        if (ask_yn('Do you want to apply an administrative tag on this machine?', 'y')) {
             $config->{tag} = promptUser("tag", $config->{tag});
         }
     }
 
     #Getting crontab
     if ($^O =~ /solaris/ || $^O =~ /bsd/) {
-        if (ask_yn("Do yo want to install the cron task in current user crontab ?", 'y')) {
+        if (ask_yn("Do yo want to install the cron task in current user crontab?", 'y')) {
             $crontab = 1;
         }
     } elsif (-d "/etc/cron.d") {
-        if (ask_yn("Do yo want to install the cron task in /etc/cron.d", 'y')) {
+        if (ask_yn("Do yo want to install the cron task in /etc/cron.d?", 'y')) {
             $crontab = 1;
         }
     }
@@ -195,35 +212,39 @@ unless ($nowizard) {
     }
 
     #Remove old unix agent ?
-    $remove_old_unix = ask_yn ("Should I remove the old unix_agent", 'n') unless $remove_old_unix;
+    $remove_old_unix = ask_yn ("Should I remove the old unix_agent?", 'n') unless $remove_old_unix;
 
     #Enable debug option ?
-    $config->{debug} = ask_yn("Do you want to activate debug configuration option ?", 'y') unless $config->{debug};
+    $config->{debug} = ask_yn("Do you want to activate debug configuration option?", 'y') unless $config->{debug};
 
     #Enable log file ?
     unless ($config->{logfile}) {
-        if (ask_yn("Do you want to use OCS Inventory NG UNix Unified agent log file ?", 'y')){ 
+        if (ask_yn("Do you want to use OCS Inventory NG UNix Unified agent log file?", 'y')){ 
             $config->{logfile} = promptUser('Specify log file path you want to use', $config->{logfile}, '^\/\w+', 'The location must begin with /');
         }
     }
 
     #Disable SSL option ?
     unless ($nossl) {
-        $nossl = ask_yn("Do you want disable SSL CA verification configuration option (not recommended) ?", 'n');
+        $nossl = ask_yn("Do you want disable SSL CA verification configuration option (not recommended)?", 'n');
     }
 
-    #Set CA certificate path ?
+    #Set CA certificates file path ?
     unless ($config->{ca}) {
-        if (ask_yn("Do you want to set CA certificate chain file path ?", 'y')){ 
-            $config->{ca} = promptUser('Specify CA certificate chain file path', $config->{ca}, '^\/\w+', 'The location must begin with /');
+        if (ask_yn("Do you want to set CA certificates file path?", 'y')){
+            $config->{ca} = promptUser('Specify CA certificates file path', $config->{ca}, '^\/\w+', 'The location must begin with /');
         }
     }
 
+    #Disable software inventory ?
+    unless ($nosoftware) {
+        $nossl = ask_yn("Do you want disable software inventory?", 'n');
+    }
     #Enable download feature ?
     $download = ask_yn("Do you want to use OCS-Inventory software deployment feature?", 'y') unless $download;
 
     #Enable SNMP feature ?
-    $snmp = ask_yn("Do you want to use OCS-Inventory SNMP scans feature?", 'y') unless $snmp;
+    $config->{snmp} = ask_yn("Do you want to use OCS-Inventory SNMP scans feature?", 'y') unless $config->{snmp};
 
     #Run agent after configuration ?
     $now = ask_yn("Do you want to send an inventory of this machine?", 'y') unless $now;
@@ -343,6 +364,13 @@ if (!-d $config->{basevardir}) {
 #Disabling SSL verification if asked
 $config->{ssl} = 0 if $nossl;
 
+#Disabling software inventory 
+if ($nosoftware) {
+    $config->{nosoftware} = 1;
+} else {
+    $config->{nosoftware} = 0;
+}
+
 #Creating configuration directory 
 $configdir = "/etc/ocsinventory-agent" unless $configdir;  #If not set in command line
 
@@ -425,8 +453,8 @@ print MODULE "# This mechanism goal is to launch agent extension modules\n";
 print MODULE "\n";
 print MODULE ($download?'':'#');
 print MODULE "use Ocsinventory::Agent::Modules::Download;\n";
-print MODULE ($snmp?'':'#');
-print MODULE "use Ocsinventory::Agent::Modules::Snmp;\n";
+print MODULE ($config->{snmp}?'':'#');
+print MODULE "use Ocsinventory::Agent::Modules::SnmpScan;\n";
 print MODULE "\n";
 print MODULE "# DO NOT REMOVE THE 1;\n";
 print MODULE "1;\n";
@@ -482,7 +510,7 @@ sub ask_yn {
         return 1 if $line =~ /^y$/;
         return if $line =~ /^n$/;
         if ($cpt-- < 0) {
-            print STDERR "to much user input, exit...\n";
+            print STDERR "too much user input, exit...\n";
             exit(0);
         }
     }
@@ -505,7 +533,7 @@ sub promptUser {
             last;
         }
         if ($cpt-- < 0) {
-            print STDERR "to much user input, exit...\n";
+            print STDERR "too much user input, exit...\n";
             exit(0);
         }
     }
